==> formant-1.230.2-py2.py3-none-any.whl: formant/sdk/cloud/v2/formant_admin_api_client/api/file/file_controller_complete_upload.py <==
from http import HTTPStatus
from typing import Any, Dict

import httpx

from ...client import AuthenticatedClient
from ...models.complete_upload_request import CompleteUploadRequest
from ...types import Response


def _get_kwargs(
    *,
    client: AuthenticatedClient,
    json_body: CompleteUploadRequest,
) -> Dict[str, Any]:
    url = "{}/files/complete-upload".format(client.base_url)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    json_json_body = json_body.to_dict()

    return {
        "method": "post",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "json": json_json_body,
    }


def _build_response(*, response: httpx.Response) -> Response[Any]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=None,
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    json_body: CompleteUploadRequest,
) -> Response[Any]:
    """Complete upload

     Complete a file upload. Must be preceded by Begin Upload endpoint call.
    Resource: fileStorage
    Authorized roles: administrator

    Args:
        json_body (CompleteUploadRequest):

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(response=response)


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    json_body: CompleteUploadRequest,
) -> Response[Any]:
    """Complete upload

     Complete a file upload. Must be preceded by Begin Upload endpoint call.
    Resource: fileStorage
    Authorized roles: administrator

    Args:
        json_body (CompleteUploadRequest):

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

    return _build_response(response=response)

==> formant-1.268.2-py2.py3-none-any.whl: formant/sdk/cloud/v2/formant_admin_api_client/api/file/file_controller_complete_upload.py <==
from http import HTTPStatus
from typing import Any, Dict

import httpx

from ...client import AuthenticatedClient
from ...models.complete_upload_request import CompleteUploadRequest
from ...types import Response


def _get_kwargs(
    *,
    client: AuthenticatedClient,
    json_body: CompleteUploadRequest,

) -> Dict[str, Any]:
    url = "{}/files/complete-upload".format(
        client.base_url)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    

    

    

    json_json_body = json_body.to_dict()



    

    return {
	    "method": "post",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "json": json_json_body,
    }




def _build_response(*, response: httpx.Response) -> Response[Any]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=None,
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    json_body: CompleteUploadRequest,

) -> Response[Any]:
    """Complete upload

     Complete a file upload. Must be preceded by Begin Upload endpoint call.
    Resource: fileStorage
    Authorized roles: administrator

    Args:
        json_body (CompleteUploadRequest):

    Returns:
        Response[Any]
    """


    kwargs = _get_kwargs(
        client=client,
json_body=json_body,

    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(response=response)


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    json_body: CompleteUploadRequest,

) -> Response[Any]:
    """Complete upload

     Complete a file upload. Must be preceded by Begin Upload endpoint call.
    Resource: fileStorage
    Authorized roles: administrator

    Args:
        json_body (CompleteUploadRequest):

    Returns:
        Response[Any]
    """


    kwargs = _get_kwargs(
        client=client,
json_body=json_body,

    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(
            **kwargs
        )

    return _build_response(response=response)
